from enum import Enum


class CaptchaTypes(Enum):
    """An enumeration of the supported types of Captcha"""

    RECAPTCHA_V3 = "recaptchav3"

    @property
    def values_as_str(self) -> str:
        """Return the printed list of values"""
        return ", ".join(el.value for el in list(self))

    def __iter__(self):
        return iter(self)


class CaptchaResponseKeys:
    """The key names of the Captcha responses"""

    RECAPTCHA_V3 = "g-recaptcha-response"


class CaptchaVerifyLocations:
    """The URL of the captcha verification endpoints"""

    RECAPTCHA_V3 = ("www.google.com", "/recaptcha/api/siteverify")



import os

from simple_mailer.dispatcher import Dispatcher


def test_dispatcher_sends_email(smtpd, urlencoded_post_request):
    Dispatcher(data={"email": "me@example.com"}).dispatch()
    assert smtpd.sent_mail


def test_dispatcher_sends_text_templated_email(smtpd, urlencoded_post_request):
    Dispatcher(data={"email": "you@example.net", "msg": "hello!"}).dispatch()
    assert len(smtpd.sent_mail) == 1
    body = smtpd.sent_mail[0].body.decode("utf8")
    assert "Form submission" in body
    assert "msg: hello!" in body
    assert "timestamp_utc" in body


def test_dispatcher_filter_unwanted_fields(smtpd, urlencoded_post_request):
    os.environ.setdefault("FIELDS_EXCLUDED", "subscribe_me")
    Dispatcher().parse_request(urlencoded_post_request).dispatch()
    assert len(smtpd.sent_mail) == 1
    body = smtpd.sent_mail[0].body.decode("utf8")
    assert "subscribe_me" not in body



import http.client
import json

from simple_mailer.config import Config


def is_valid_recaptcha_v3_response(captcha_response: str) -> bool:
    """The given ReCaptcha v3 response has been validated successfully"""
    config = Config()
    host, path = config.CAPTCHA_VERIFY_LOCATION
    params = {"secret": config.CAPTCHA_SECRET, "response": captcha_response}
    headers = {
        "Content-type": "application.json",
        "Accept": "application/json",
    }
    conn = http.client.HTTPSConnection(host)
    conn.request("POST", path, json.dumps(params), headers)
    http_response = conn.getresponse()
    if http_response.status == 200:
        data = json.load(http_response)
        if data["success"]:
            return True
    return False



import random
import string

from simple_mailer import constants
from simple_mailer.web import get_application
from webtest import TestApp


def test_recaptcha_v3(smtpd, captcha_server, mocked_https_client):
    app = TestApp(get_application())
    recaptcha_response = "".join(
        random.choice(string.ascii_letters) for idx in range(40)
    )
    response = app.post(
        "/mail",
        {
            "email": "me@example.com",
            "subscribe_me": True,
            constants.CaptchaResponseKeys.RECAPTCHA_V3: recaptcha_response,
        },
    )
    assert response.status_code == 200
    assert smtpd.sent_mail



#!/usr/bin/env python

import configparser
import re

from setuptools import setup, find_packages


def long_description():
    with open('README.md') as fd:
        return fd.read()


def _get_pyproject_cfg():
    parser = configparser.ConfigParser()
    with open('pyproject.toml') as fd:
        parser.read_file(fd)
    return parser


def _extract_version(text):
    try:
        return re.findall(r'[\w\.]+', text)[0]
    except IndexError:
        return ''


def version():
    return _get_pyproject_cfg()['tool.poetry']['version'].strip('"')


def install_requires():
    cfg = _get_pyproject_cfg()
    deps = cfg['tool.poetry.dependencies']
    seq = (
        (k, _extract_version(v)) for k, v in deps.items() if k != 'python'
    )
    return [f'{k}=={v}' for k, v in seq]


setup(
    name='simple-mailer',
    version=version(),
    author='Rigel Di Scala',
    author_email='zedr@zedr.com',
    description='A simple mailer for web forms',
    license='MIT',
    long_description=long_description(),
    long_description_content_type='text/markdown',
    url='https://github.com/zedr/simple-mailer',
    install_requires=install_requires(),
    package_dir={'': 'src'},
    packages=['simple_mailer'],
    py_modules=['simple_mailer.web'],
    include_package_data=True,
    entry_points={
        'console_scripts': ['simple-mailer=simple_mailer.web:run_application']
    },
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.7'
)
